@@ -165,4 +165,4 @@ if __name__ == "__main__":
     import doctest
     from test_manifest import manifest
     from job import Job
-    doctest.testmod()
+    doctest.testmod(raise_on_error=True)
